```
import datetime
import pickle
import sys
import os
from sklearn.model_selection import RandomizedSearchCV
from sklearn.svm import SVC
from sklearn.ensemble import RandomForestClassifier
from sklearn.linear_model import LogisticRegression
from lightgbm import LGBMClassifier
from keras.models import Sequential
from keras.layers import Dense
from sklearn.metrics import roc_auc_score


X_train = df_X_train_2.copy()
y_train = df_y_train.copy().astype('int')
X_test = df_X_test_2.copy()
y_test = df_y_test.copy().astype('int')


time_st = datetime.datetime.now().strftime('%Y%m%d_%H%M%S')

target_data = {}
target_data['X_train'] = X_train
target_data['y_train'] = y_train
target_data['X_test'] = X_test
target_data['y_test'] = y_test

def train(objective,model_name,data_dict):
    ref_time = datetime.datetime.now().strftime('%Y%m%d_%H%M%S')
    path = '.'
    n_iter_search = 1000
    X_train, y_train, X_test, y_test = data_dict['X_train'], data_dict['y_train'], data_dict['X_test'], data_dict['y_test']
    n_cols = X_train.shape[1]

    print(objective,model_name)

    if model_name == 'LR':
        param_dist = {
                        'C': [0.001, 0.01,0.1, 1.0],
                        'penalty': ['l1', 'l2']
                     }
        clf = LogisticRegression()
        random_search = RandomizedSearchCV(clf,
                                            param_distributions=param_dist,
                                            n_iter=n_iter_search,
                                            cv=5,
                                            scoring='roc_auc',
                                            n_jobs=-1,
                                            verbose=1,
                                            )
        random_search.fit(X_train, y_train.values.ravel())
        clf_best = random_search.best_estimator_
        clf_best.fit(X_train, y_train.values.ravel())
        y_predict_proba = clf_best.predict_proba(X_test)[:,1]

    if model_name == 'RF':
        param_dist = {
                    'n_estimators': range(80,200,4),
                    'max_depth': range(2,15,1),
                    'min_samples_split': np.linspace(0.1, 1.0, 10, endpoint=True),
                    'min_samples_leaf': np.linspace(0.1, 0.5, 5, endpoint=True),
                     }
        clf = RandomForestClassifier()
        random_search = RandomizedSearchCV(clf,
                                            param_distributions=param_dist,
                                            n_iter=n_iter_search,
                                            cv=5,
                                            scoring='roc_auc',
                                            n_jobs=-1,
                                            verbose=1,
                                            )
        random_search.fit(X_train, y_train.values.ravel())
        clf_best = random_search.best_estimator_
        clf_best.fit(X_train, y_train.values.ravel())
        y_predict_proba = clf_best.predict_proba(X_test)[:,1]

    if model_name == 'GBM':
        param_dist = {
                    "learning_rate": [0.001, 0.01, 0.025, 0.05, 0.075, 0.1, 0.15, 0.2],
                    "max_depth":range(2,63,1),
                    "subsample":[0.5, 0.6, 0.7, 0.8, 0.85, 0.9, 0.95, 1.0],
                    "n_estimators":range(10,210,10),
                    "num_leaves":range(10,210,10), 12).astype('float32'),
                    }
        clf = LGBMClassifier()
        random_search = RandomizedSearchCV(clf,
                                            param_distributions=param_dist,
                                            n_iter=n_iter_search,
                                            cv=5,
                                            scoring='roc_auc',
                                            n_jobs=-1,
                                            verbose=1,
                                            )
        random_search.fit(X_train, y_train.values.ravel())
        clf_best = random_search.best_estimator_
        clf_best.fit(X_train, y_train.values.ravel())
        y_predict_proba = clf_best.predict_proba(X_test)[:,1]

    if model_name == 'SVM':
        clf = SVC(probability=True)
        clf_best = clf
        clf_best.fit(X_train, y_train.values.ravel())
        y_predict_proba = clf_best.predict_proba(X_test)[:,1]
    
    if model_name == 'NN':
        clf = Sequential()
        clf.add(Dense(100, activation='relu', input_shape=(n_cols,)))
        clf.add(Dense(100, activation='relu'))
        clf.add(Dense(1, activation='sigmoid'))
        clf.compile(loss='binary_crossentropy', optimizer='adam', metrics=['accuracy'])
        clf.fit(X_train, y_train.values.ravel(), epochs=10, batch_size=10)
        clf_best = clf
        y_predict_proba = clf_best.predict_proba(X_test)[:,0]
        
    path_gs = './gs_result_'+time_st+'/'+objective+'/'+model_name
    os.makedirs(path_gs,exist_ok=True)
    original = sys.stdout
    sys.stdout = open(path_gs+'/'+'gs_'+ref_time+'.txt', "w")
    try:
        print(report(random_search.cv_results_))
        print('Test Accuracy:')
        print(roc_auc_score(y_test, y_predict_proba))
    except:
        print(roc_auc_score(y_test, y_predict_proba))

    sys.stdout = original

    try:
        pickle.dump(clf_best, open(path_gs+'/'+'model_'+ref_time+'.pkl', 'wb'))
    except:
        clf_best.save(path_gs+'/'+'model_'+ref_time+'/')

    with open(path_gs+'/'+'y_predict_proba_'+ref_time+'.txt', "w") as f:
        for h in y_predict_proba:
            f.write(str(h)+'\n')
            
for _ in range(50):
    for obj in ['D']:
        for model in ['SVM','GBM','LR','RF','NN']:
            train(obj,model,target_data)
```